@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -32,19 +31,21 @@
 
 """|UDM| allocators to allocate and lock resources for |LDAP| object creation."""
 
+from collections.abc import Sequence  # noqa: F401
 from logging import getLogger
-from typing import Sequence, overload  # noqa: F401
+from typing import overload
 
 import ldap
 from ldap.filter import filter_format
 
+import univention.admin.localization
 import univention.admin.locking
 import univention.admin.uexceptions
-from univention.admin import configRegistry, localization
+from univention.admin._ucr import configRegistry
 
 
 try:
-    from typing import Literal  # noqa: F401
+    from typing import Literal
     _TypesUidGid = Literal["uidNumber", "gidNumber"]
     _Types = Literal["uidNumber", "gidNumber", "uid", "gid", "sid", "domainSid", "mailPrimaryAddress", "mailAlternativeAddress", "aRecord", "mac", "groupName", "cn-uid-position", "univentionObjectIdentifier"]
     _Scopes = Literal["base", "one", "sub", "domain"]
@@ -53,7 +54,7 @@ except ImportError:
 
 
 log = getLogger('ADMIN')
-translation = localization.translation('univention/admin')
+translation = univention.admin.localization.translation('univention/admin')
 _ = translation.translate
 
 _type2attr = {
@@ -246,11 +247,8 @@ def acquireUnique(
         if not lo.searchDn(base=searchBase, filter=filter_format('%s=%s', (attr, value))):
             log.debug('ALLOCATE return %s', value)
             return value
-    # this is the else-part to the uniqueness search above, if an entry with the to-be-locked attribute already exists in LDAP
-    # before that search, we created a lock-object already, which we don't need anymore as we are aborting anyway
-    # other processes also don't need the lock, as they will fail here again due to the same search
-    univention.admin.locking.unlock(lo, position, type, value.encode('utf-8'), scope=scope)
-    raise univention.admin.uexceptions.noLock(_('The attribute %r could not get locked. The value is already in use.') % (type,))
+
+    raise univention.admin.uexceptions.noLock(_('The attribute %r could not get locked.') % (type,))
 
 
 @overload
