@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
@@ -31,24 +30,26 @@
 
 """|UDM| functions to check and create blocklist entries"""
 
+from __future__ import annotations
 
 import hashlib
 import re
+from collections.abc import Iterable  # noqa: F401
 from datetime import datetime
-from typing import TYPE_CHECKING, Any, Iterable  # noqa: F401
+from typing import TYPE_CHECKING
 
 import ldap
 from dateutil.relativedelta import relativedelta
 
+import univention.admin.localization
 import univention.admin.uexceptions
 import univention.admin.uldap
-from univention.admin import configRegistry
+from univention.admin._ucr import configRegistry
 
 
 if TYPE_CHECKING:
     import univention.admin.handlers
-    import univention.admin.handlers.blocklists.list
-    import univention.admin.modules
+    import univention.admin.handlers.blocklists.list  # noqa: TCH004
 
 
 translation = univention.admin.localization.translation('univention.admin.handlers')
@@ -119,9 +120,9 @@ def blocklist_enabled(udm_obj):
 
 def get_blocklist_values_from_udm_property(udm_property_value, udm_property_name):
     # type: (Any, str) -> list[Any]
-    if isinstance(udm_property_value, (str, unicode)):
+    if isinstance(udm_property_value, str | unicode):
         return [udm_property_value]
-    if not isinstance(udm_property_value, list) or not all(isinstance(mem, (str, unicode)) for mem in udm_property_value):
+    if not isinstance(udm_property_value, list) or not all(isinstance(mem, str | unicode) for mem in udm_property_value):
         raise RuntimeError('The property %r uses a complex syntax. This is not supported for blocklist objects.' % udm_property_name)
     return udm_property_value
 
