@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -33,7 +32,7 @@
 """|UDM| functions for creating crontab entries."""
 
 
-from typing import Mapping, Sequence  # noqa: F401
+from collections.abc import Mapping, Sequence  # noqa: F401
 
 
 def month_map(month):
