@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -263,7 +262,7 @@ layout.append(member_role_layout())
 
 def unmapSambaRid(oldattr):
     sid = oldattr.get('sambaSID', [b''])[0].decode('ASCII')
-    sid, has_rid, rid = sid.rpartition(u'-')
+    sid, has_rid, rid = sid.rpartition('-')
     if has_rid and rid.isdigit():
         return rid
 
@@ -284,7 +283,7 @@ mapping.register('univentionSourceIAM', 'univentionSourceIAM', None, univention.
 register_member_role_mapping(mapping)
 
 
-class AgingCache(object):
+class AgingCache:
 
     def __new__(type, *args, **kwargs):
         # Falls es noch keine Instanz dieser Klasse gibt, wird eine erstellt und in _the_instance abgelegt.
@@ -464,7 +463,7 @@ class object(univention.admin.handlers.simpleLdap):
 
     def _ldap_pre_ready(self):
         # type: () -> None
-        super(object, self)._ldap_pre_ready()
+        super()._ldap_pre_ready()
 
         # get lock for name
         if self['name'] and (not self.exists() or self.hasChanged('name') and self['name'].lower() != self.oldinfo['name'].lower()):
@@ -482,7 +481,7 @@ class object(univention.admin.handlers.simpleLdap):
 
     def _ldap_pre_create(self):
         # type: () -> None
-        super(object, self)._ldap_pre_create()
+        super()._ldap_pre_create()
 
         if self['gidNumber']:
             univention.admin.allocators.acquireUnique(self.lo, self.position, 'gidNumber', self['gidNumber'], 'gidNumber', scope='base')
@@ -500,7 +499,7 @@ class object(univention.admin.handlers.simpleLdap):
 
     def _ldap_pre_modify(self):
         # type: () -> None
-        super(object, self)._ldap_pre_modify()
+        super()._ldap_pre_modify()
         self.check_for_group_recursion()
         self.check_ad_group_type_change()
 
@@ -510,7 +509,7 @@ class object(univention.admin.handlers.simpleLdap):
 
     def _ldap_addlist(self):
         # type: () -> list
-        al = super(object, self)._ldap_addlist()
+        al = super()._ldap_addlist()
 
         if 'posix' not in self.options:
             al.append(('objectClass', b'organizationalRole'))  # any STRUCTURAL class with 'cn'
@@ -520,7 +519,6 @@ class object(univention.admin.handlers.simpleLdap):
     def _ldap_modlist(self):
         # type: () -> list
         ml = univention.admin.handlers.simpleLdap._ldap_modlist(self)
-        t1 = time.time()
 
         self._samba_sid = None
         if 'samba' in self.options:
@@ -537,29 +535,24 @@ class object(univention.admin.handlers.simpleLdap):
                 ml.append(('sambaSID', self.oldattr.get('sambaSID', [b'']), [sid.encode('ASCII')]))
                 self._samba_sid = sid
 
-        old = set(self.oldinfo.get('users', []) + self.oldinfo.get('hosts', []) + self.oldinfo.get('nestedGroup', []))
-        new = set(self.info.get('users', []) + self.info.get('hosts', []) + self.info.get('nestedGroup', []))
+        old = DN.set(self.oldinfo.get('users', []) + self.oldinfo.get('hosts', []) + self.oldinfo.get('nestedGroup', []))
+        new = DN.set(self.info.get('users', []) + self.info.get('hosts', []) + self.info.get('nestedGroup', []))
         if old != new:
             # create lists for uniqueMember entries to be added or removed
-            uniqueMemberAdd = DN.set(new - old)
-            uniqueMemberRemove = DN.set(old - new)
-            # old and new might contain the same DNs (as str) but with different case.
-            # After unifying the strings to DN objects there might be identical DNs that are
-            # subtracted from uniqueMemberAdd and uniqueMemberRemove.
-            sameMembers = uniqueMemberAdd & uniqueMemberRemove
-            if sameMembers:
-                uniqueMemberRemove = uniqueMemberRemove - sameMembers
-                uniqueMemberAdd = uniqueMemberAdd - sameMembers
+            uniqueMemberAdd = list(DN.values(new - old))
+            uniqueMemberRemove = list(DN.values(old - new))
+            old = list(DN.values(old))
+            new = list(DN.values(new))
 
-            def getUidList(uniqueMembers):  # type: (List[DN]) -> List[str]
+            def getUidList(uniqueMembers):
                 result = []
                 for uniqueMember in uniqueMembers:
-                    dn = uniqueMember._dn[0]
+                    dn = ldap.dn.str2dn(uniqueMember)[0]
                     try:
                         result.append([x[1] for x in dn if x[0].lower() == 'uid'][0])  # noqa: RUF015
                     except IndexError:
                         # UID is not stored in DN --> fetch UID by DN
-                        uid_list = self.lo.getAttr(uniqueMember.dn, 'uid')
+                        uid_list = self.lo.getAttr(uniqueMember, 'uid')
                         # a group have no uid attribute, see Bug #12644
                         if uid_list:
                             result.append(uid_list[0].decode('UTF-8'))
@@ -578,11 +571,12 @@ class object(univention.admin.handlers.simpleLdap):
             memberUidRemove = getUidList(uniqueMemberRemove)
 
             if uniqueMemberRemove:
-                uniqueMemberRemove = [x.encode('UTF-8') for x in DN.values(uniqueMemberRemove)]
+                uniqueMemberRemove = keepCase(uniqueMemberRemove, old)
+                uniqueMemberRemove = [x.encode('UTF-8') for x in uniqueMemberRemove]
                 ml.append(('uniqueMember', uniqueMemberRemove, ''))
 
             if uniqueMemberAdd:
-                uniqueMemberAdd = [x.encode('UTF-8') for x in DN.values(uniqueMemberAdd)]
+                uniqueMemberAdd = [x.encode('UTF-8') for x in uniqueMemberAdd]
                 ml.append(('uniqueMember', '', uniqueMemberAdd))
 
             oldMemberUids = [x.decode('UTF-8') for x in self.oldattr.get('memberUid', ())]
@@ -595,18 +589,16 @@ class object(univention.admin.handlers.simpleLdap):
                 memberUidAdd = [x.encode('UTF-8') for x in memberUidAdd]
                 ml.append(('memberUid', '', memberUidAdd))
 
-            log.debug('groups/group: _ldap_modlist(): %.3fs', time.time() - t1)
-
         return ml
 
     def _ldap_post_create(self):
         # type: () -> None
-        super(object, self)._ldap_post_create()
+        super()._ldap_post_create()
         self.__update_membership()
 
     def _ldap_post_modify(self):
         # type: () -> None
-        super(object, self)._ldap_post_modify()
+        super()._ldap_post_modify()
         self.__update_membership()
         old_sid = self.oldattr.get('sambaSID', [b''])[0].decode('ASCII')
         if self._samba_sid and self._samba_sid != old_sid:
@@ -615,7 +607,7 @@ class object(univention.admin.handlers.simpleLdap):
 
     def _ldap_pre_remove(self):
         # type: () -> None
-        super(object, self)._ldap_pre_remove()
+        super()._ldap_pre_remove()
         self.open()
         # is this group in mentioned in settings/default?
         try:
@@ -647,7 +639,7 @@ class object(univention.admin.handlers.simpleLdap):
 
     def _ldap_post_remove(self):
         # type: () -> None
-        super(object, self)._ldap_post_remove()
+        super()._ldap_post_remove()
         for group in self.info.get('memberOf', []):
             if isinstance(group, list):
                 group = group[0]
@@ -661,7 +653,7 @@ class object(univention.admin.handlers.simpleLdap):
 
     def _ldap_post_move(self, olddn):
         # type: (str) -> None
-        super(object, self)._ldap_post_move(olddn)
+        super()._ldap_post_move(olddn)
         settings_module = univention.admin.modules._get('settings/default')
         settings_object = univention.admin.objects.get(settings_module, None, self.lo, position='', dn='cn=default,cn=univention,%s' % self.lo.base)
         settings_object.open()
@@ -812,7 +804,7 @@ class object(univention.admin.handlers.simpleLdap):
         else:
             childs = grpdn2childgrpdns[dn]
 
-        new_parents = parents + [dn]
+        new_parents = [*parents, dn]
         for childgrp in childs:
             if childgrp.lower() in new_parents:
                 dnCircle = new_parents[new_parents.index(childgrp.lower()):] + [childgrp.lower()]
@@ -931,10 +923,10 @@ class object(univention.admin.handlers.simpleLdap):
         searchResult = self.lo.search(filter='objectClass=sambaDomain', attr=['sambaSID'])
         new_groupType = self.info.get('adGroupType', 0)
         if self.__is_groupType_local(new_groupType):
-            sid = u'S-1-5-32-' + self['sambaRID']
+            sid = 'S-1-5-32-' + self['sambaRID']
         else:
             domainsid = searchResult[0][1]['sambaSID'][0].decode('ASCII')
-            sid = domainsid + u'-' + rid
+            sid = domainsid + '-' + rid
         try:
             return self.request_lock('sid', sid)
         except univention.admin.uexceptions.noLock:
@@ -949,7 +941,7 @@ class object(univention.admin.handlers.simpleLdap):
         elif self.s4connector_present and not self.__is_groupType_local(new_groupType):
             # In this case Samba 4 must create the SID, the s4 connector will sync the
             # new sambaSID back from Samba 4.
-            return u'S-1-4-%s' % (gidNum,)
+            return 'S-1-4-%s' % (gidNum,)
 
         num = gidNum
         generateDomainLocalSid = self.__is_groupType_local(new_groupType)
