@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -32,22 +31,18 @@
 
 """|UDM| module for all mail objects"""
 
-from typing import TYPE_CHECKING
 
+import univention.admin
 import univention.admin.filter
 import univention.admin.handlers
 import univention.admin.handlers.mail.domain
 import univention.admin.handlers.mail.folder
 import univention.admin.handlers.mail.lists
 import univention.admin.localization
+import univention.admin.uldap
 from univention.admin.layout import Tab
 
 
-if TYPE_CHECKING:
-    import univention.admin
-    import univention.admin.uldap
-
-
 translation = univention.admin.localization.translation('univention.admin.handlers.mail')
 _ = translation.translate
 
