@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -32,8 +31,8 @@
 
 """|UDM| module for all setting objects"""
 
-from typing import TYPE_CHECKING
 
+import univention.admin
 import univention.admin.filter
 import univention.admin.handlers
 import univention.admin.handlers.settings.default
@@ -41,11 +40,7 @@ import univention.admin.handlers.settings.directory
 import univention.admin.handlers.settings.license
 import univention.admin.handlers.settings.usertemplate
 import univention.admin.localization
-
-
-if TYPE_CHECKING:
-    import univention.admin
-    import univention.admin.uldap
+import univention.admin.uldap
 
 
 translation = univention.admin.localization.translation('univention.admin.handlers.settings')
