@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -32,21 +31,23 @@
 
 """|UDM| hook definitions for modifying |LDAP| calls when objects are created, modifier or deleted."""
 
+from __future__ import annotations
+
 import os
 import sys
 import warnings
 from logging import getLogger
-from typing import TYPE_CHECKING, Any, List, Tuple, Union  # noqa: F401
+from typing import TYPE_CHECKING, Any
 
 from univention.admin import localization
 
 
 if TYPE_CHECKING:
-    import univention.admin.handlers  # noqa: F401
-    AddList = List[Tuple[str, List[str]]]
-    _Mod2 = Tuple[str, List[str]]
-    _Mod3 = Tuple[str, List[str], List[str]]
-    ModList = List[Union[_Mod2, _Mod3]]
+    import univention.admin.handlers
+    AddList = list[tuple[str, list[str]]]
+    _Mod2 = tuple[str, list[str]]
+    _Mod3 = tuple[str, list[str], list[str]]
+    ModList = list[_Mod2 | _Mod3]
 
 log = getLogger('ADMIN')
 
@@ -54,8 +55,7 @@ translation = localization.translation('univention/admin')
 _ = translation.translate
 
 
-def import_hook_files():
-    # type: () -> None
+def import_hook_files() -> None:
     """Load all additional hook files from :file:`.../univention/admin/hooks.d/*.py`"""
     for dir_ in sys.path:
         hooks_d = os.path.join(dir_, 'univention/admin/hooks.d/')
@@ -70,7 +70,7 @@ def import_hook_files():
                     log.exception('admin.hook.import_hook_files: loading %r failed', fn)
 
 
-class simpleHook(object):
+class simpleHook:
     """Base class for a |UDM| hook performing logging."""
 
     type = 'simpleHook'
@@ -80,8 +80,7 @@ class simpleHook(object):
     # methods, use obj.lo and obj.position.
     #
 
-    def hook_open(self, obj):
-        # type: (univention.admin.handlers.simpleLdap) -> None
+    def hook_open(self, obj: univention.admin.handlers.simpleLdap) -> None:
         """
         This method is called by the default open handler just before the current state of all properties is saved.
 
@@ -89,8 +88,7 @@ class simpleHook(object):
         """
         log.debug('admin.syntax.hook.simpleHook: _open called')
 
-    def hook_ldap_pre_create(self, obj):
-        # type: (univention.admin.handlers.simpleLdap) -> None
+    def hook_ldap_pre_create(self, obj: univention.admin.handlers.simpleLdap) -> None:
         """
         This method is called before an |UDM| object is created.
         It is called after the module validated all properties but before the add-list is created.
@@ -99,8 +97,7 @@ class simpleHook(object):
         """
         log.debug('admin.syntax.hook.simpleHook: _ldap_pre_create called')
 
-    def hook_ldap_addlist(self, obj, al=[]):
-        # type: (univention.admin.handlers.simpleLdap, AddList) -> AddList
+    def hook_ldap_addlist(self, obj: univention.admin.handlers.simpleLdap, al: AddList = []) -> AddList:
         """
         This method is called before an |UDM| object is created.
 
@@ -113,8 +110,7 @@ class simpleHook(object):
         log.debug('admin.syntax.hook.simpleHook: _ldap_addlist called')
         return al
 
-    def hook_ldap_post_create(self, obj):
-        # type: (univention.admin.handlers.simpleLdap) -> None
+    def hook_ldap_post_create(self, obj: univention.admin.handlers.simpleLdap) -> None:
         """
         This method is called after the object was created in |LDAP|.
 
@@ -122,8 +118,7 @@ class simpleHook(object):
         """
         log.debug('admin.syntax.hook.simpleHook: _ldap_post_create called')
 
-    def hook_ldap_pre_modify(self, obj):
-        # type: (univention.admin.handlers.simpleLdap) -> None
+    def hook_ldap_pre_modify(self, obj: univention.admin.handlers.simpleLdap) -> None:
         """
         This method is called before an |UDM| object is modified.
         It is called after the module validated all properties but before the modification-list is created.
@@ -132,8 +127,7 @@ class simpleHook(object):
         """
         log.debug('admin.syntax.hook.simpleHook: _ldap_pre_modify called')
 
-    def hook_ldap_modlist(self, obj, ml=[]):
-        # type: (univention.admin.handlers.simpleLdap, ModList) -> ModList
+    def hook_ldap_modlist(self, obj: univention.admin.handlers.simpleLdap, ml: ModList = []) -> ModList:
         """
         This method is called before an |UDM| object is created or modified.
 
@@ -144,8 +138,7 @@ class simpleHook(object):
         log.debug('admin.syntax.hook.simpleHook: _ldap_modlist called')
         return ml
 
-    def hook_ldap_post_modify(self, obj):
-        # type: (univention.admin.handlers.simpleLdap) -> None
+    def hook_ldap_post_modify(self, obj: univention.admin.handlers.simpleLdap) -> None:
         """
         This method is called after the object was modified in |LDAP|.
 
@@ -153,8 +146,7 @@ class simpleHook(object):
         """
         log.debug('admin.syntax.hook.simpleHook: _ldap_post_modify called')
 
-    def hook_ldap_pre_remove(self, obj):
-        # type: (univention.admin.handlers.simpleLdap) -> None
+    def hook_ldap_pre_remove(self, obj: univention.admin.handlers.simpleLdap) -> None:
         """
         This method is called before an |UDM| object is removed.
 
@@ -162,8 +154,7 @@ class simpleHook(object):
         """
         log.debug('admin.syntax.hook.simpleHook: _ldap_pre_remove called')
 
-    def hook_ldap_post_remove(self, obj):
-        # type: (univention.admin.handlers.simpleLdap) -> None
+    def hook_ldap_post_remove(self, obj: univention.admin.handlers.simpleLdap) -> None:
         """
         This method is called after the object was removed from |LDAP|.
 
@@ -193,8 +184,7 @@ class AttributeHook(simpleHook):
 
     version = 1  # don't subclass if you don't set version to 2!
 
-    def hook_open(self, obj):
-        # type: (univention.admin.handlers.simpleLdap) -> None
+    def hook_open(self, obj: univention.admin.handlers.simpleLdap) -> None:
         """
         Open |UDM| object by loading value from |LDAP|.
 
@@ -209,8 +199,7 @@ class AttributeHook(simpleHook):
         log.debug('admin.syntax.hook.AttributeHook: Setting UDM value from %r to %r', old_value, new_value)
         obj[self.udm_attribute_name] = new_value
 
-    def hook_ldap_addlist(self, obj, al):
-        # type: (univention.admin.handlers.simpleLdap, AddList) -> AddList
+    def hook_ldap_addlist(self, obj: univention.admin.handlers.simpleLdap, al: AddList) -> AddList:
         """
         Extend |LDAP| add list.
 
@@ -220,8 +209,7 @@ class AttributeHook(simpleHook):
         """
         return self.hook_ldap_modlist(obj, al)
 
-    def hook_ldap_modlist(self, obj, ml):
-        # type: (univention.admin.handlers.simpleLdap, ModList) -> ModList
+    def hook_ldap_modlist(self, obj: univention.admin.handlers.simpleLdap, ml: ModList) -> ModList:
         """
         Extend |LDAP| modification list.
 
@@ -256,8 +244,7 @@ class AttributeHook(simpleHook):
             new_ml.append((self.ldap_attribute_name, old_value, new_value))
         return new_ml
 
-    def map_attribute_value_to_ldap(self, value):
-        # type: (Any) -> list[bytes]
+    def map_attribute_value_to_ldap(self, value: Any) -> list[bytes]:
         """
         Return value as it shall be saved in |LDAP|.
 
@@ -266,8 +253,7 @@ class AttributeHook(simpleHook):
         """
         return value
 
-    def map_attribute_value_to_udm(self, value):
-        # type: (list[bytes]) -> Any
+    def map_attribute_value_to_udm(self, value: list[bytes]) -> Any:
         """
         Return value as it shall be used in |UDM| objects.
 
