@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -36,8 +35,8 @@
 import datetime
 import inspect
 import time
+from collections.abc import Sequence
 from logging import getLogger
-from typing import Sequence, Type, Union  # noqa: F401
 
 import ldap.dn
 
@@ -50,29 +49,29 @@ log = getLogger('ADMIN')
 translation = localization.translation('univention/admin')
 _ = translation.translate
 
-_Types = Union[Type[object], Sequence[Type[object]]]
+_Types = type[object] | Sequence[type[object]]
 
 
-class TypeHint(object):
-    _python_types = object  # type: _Types
+class TypeHint:
+    _python_types: _Types = object
 
     @property
     def _json_type(self):
         # in most cases, the Python type is equivalent to the JSON type
         return self._python_types
 
-    _openapi_type = None  # type: str | None
-    _openapi_format = None  # type: str | None
-    _openapi_regex = None  # type: str | None
-    _openapi_example = None  # type: str | None
-    _openapi_readonly = None  # type: bool | None
-    _openapi_writeonly = None  # type: bool | None
+    _openapi_type: str | None = None
+    _openapi_format: str | None = None
+    _openapi_regex: str | None = None
+    _openapi_example: str | None = None
+    _openapi_readonly: bool | None = None
+    _openapi_writeonly: bool | None = None
     _openapi_nullable = True  # everything which can be removed is nullable
 
     _html_element = None
     _html_input_type = None
 
-    _encoding = None  # type: str | None
+    _encoding: str | None = None
     _minimum = float('-inf')
     _maximum = float('inf')
 
@@ -285,7 +284,7 @@ class NoneType(TypeHint):
 
 
 class BooleanType(TypeHint):
-    _python_types = bool  # type: _Types
+    _python_types: _Types = bool
     _openapi_type = 'boolean'
 
     def decode_value(self, value):
@@ -328,7 +327,7 @@ class NumberType(TypeHint):
 
 
 class StringType(TypeHint):
-    _python_types = str  # type: _Types
+    _python_types: _Types = str
     _encoding = 'UTF-8'
     _openapi_type = 'string'
 
@@ -355,7 +354,7 @@ class DistinguishedNameType(StringType):
     _minimum = 3
 
     def encode_value(self, value):
-        value = super(DistinguishedNameType, self).encode_value(value)
+        value = super().encode_value(value)
         try:
             return ldap.dn.dn2str(ldap.dn.str2dn(value))
         except ldap.DECODING_ERROR:
@@ -418,10 +417,10 @@ class DateType(StringType):
     def encode_value(self, value):
         return self.syntax.from_datetime(value)
 
-    def _to_json_type(self, value):  # type: (datetime.date) -> str
+    def _to_json_type(self, value: datetime.date) -> str:
         return str(value.isoformat())
 
-    def _from_json_type(self, value):  # type: (str) -> datetime.date
+    def _from_json_type(self, value: str) -> datetime.date:
         try:
             return datetime.date(*time.strptime(value, '%Y-%m-%d')[0:3])
         except ValueError:
@@ -450,10 +449,10 @@ class TimeType(StringType):
     def encode_value(self, value):
         return self.syntax.from_datetime(value)
 
-    def _to_json_type(self, value):  # type: (datetime.time) -> str
+    def _to_json_type(self, value: datetime.time) -> str:
         return str(value.replace(microsecond=0).isoformat())
 
-    def _from_json_type(self, value):  # type: (str) -> datetime.time
+    def _from_json_type(self, value: str) -> datetime.time:
         try:
             return datetime.time(*time.strptime(value, '%H:%M:%S')[3:6])
         except ValueError:
@@ -485,10 +484,10 @@ class DateTimeType(StringType):
     def encode_value(self, value):
         return self.syntax.from_datetime(value)
 
-    def _to_json_type(self, value):  # type: (datetime.datetime) -> str
-        return u' '.join((value.date().isoformat(), value.time().replace(microsecond=0).isoformat()))
+    def _to_json_type(self, value: datetime.datetime) -> str:
+        return ' '.join((value.date().isoformat(), value.time().replace(microsecond=0).isoformat()))
 
-    def _from_json_type(self, value):  # type: (str) -> datetime.datetime
+    def _from_json_type(self, value: str) -> datetime.datetime:
         try:
             return datetime.datetime(*time.strptime(value, '%Y-%m-%dT%H:%M:%S')[:6])  # FIXME: parse Z at the end
         except ValueError:
@@ -503,7 +502,7 @@ class ArrayType(TypeHint):
 
 
 class ListType(ArrayType):
-    item_type = None  # type: Type[TypeHint] | None # must be set in subclasses
+    item_type: type[TypeHint] | None = None  # must be set in subclasses
 
     def type_check_subitems(self, value):
         item_type = self.item_type(self.property, self.property_name)
@@ -511,7 +510,7 @@ class ListType(ArrayType):
             item_type.type_check(item)
 
     def openapi_definition(self):
-        definition = super(ListType, self).openapi_definition()
+        definition = super().openapi_definition()
         definition['items'] = self.item_type(self.property, self.property_name).get_openapi_definition()
         definition['minItems'] = self._minimum
         definition['maxItems'] = self._maximum
@@ -536,7 +535,7 @@ class SetType(ListType):
         # disallow duplicates without re-arranging the order
         # This should prevent that we run into "Type or value exists: attributename: value #0 provided more than once" errors
         # we can't do it completely because equality is defined in the LDAP server schema (e.g. DN syntax: 'dc = foo' equals 'dc=foo' equals 'DC=Foo')
-        value = super(SetType, self).encode_value(value)
+        value = super().encode_value(value)
         if len(value) != len(set(value)):
             raise univention.admin.uexceptions.valueInvalidSyntax(_('Duplicated entries.'))
         return value
@@ -575,7 +574,7 @@ class ListOfItems(ArrayType):
         ]
 
     def openapi_definition(self):
-        definition = super(ListOfItems, self).openapi_definition()
+        definition = super().openapi_definition()
         definition['minItems'] = self._minimum
         definition['maxItems'] = self._maximum
         definition['uniqueItems'] = self._openapi_unique
@@ -608,7 +607,7 @@ class DictionaryType(TypeHint):
         return self.syntax.fromdict(value)
 
     def openapi_definition(self):
-        definition = super(DictionaryType, self).openapi_definition()
+        definition = super().openapi_definition()
         definition['additionalProperties'] = True
         definition['minProperties'] = self._minimum
         definition['maxProperties'] = self._maximum
@@ -626,8 +625,8 @@ class DictionaryType(TypeHint):
 
 
 class KeyValueDictionaryType(DictionaryType):
-    key_type = None  # type: _Types | None
-    value_type = None  # type: _Types | None
+    key_type: _Types | None = None
+    value_type: _Types | None = None
 
     def openapi_definition(self):
         definition = super(DictionaryType, self).openapi_definition()
@@ -642,7 +641,7 @@ class SambaLogonHours(ListType):
     _weekdays = ('Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat')
 
     def decode_value(self, value):
-        return ['{} {}-{}'.format(self._weekdays[v // 24], v % 24, v % 24 + 1) for v in value]
+        return [f'{self._weekdays[v // 24]} {v % 24}-{v % 24 + 1}' for v in value]
 
     def encode_value(self, value):
         try:
@@ -662,8 +661,8 @@ class AppcenterTranslation(KeyValueDictionaryType):
         return {k.lstrip('[').rstrip(']'): v for k, v in value}
 
     def encode_value(self, value):
-        value = ['[{}] {}'.format(k, v) for k, v in value.items()]
-        return super(AppcenterTranslation, self).encode_value(value)
+        value = [f'[{k}] {v}' for k, v in value.items()]
+        return super().encode_value(value)
 
 
 class UnixTimeinterval(IntegerType):
